<?php namespace EscapeWork\Manager\Commands;

use Illuminate\Console\Command;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;
use EscapeWork\Manager\Generators\Generator;

class CrudGenerateCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager:crud-generate';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Cria model, repositório, controller e views básicas para um CRUD';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(Generator $generator)
    {
        parent::__construct();

        $this->generator = $generator;
    }

    /**
     * Execute the console command.
     *
     * @return void
     */
    public function fire()
    {
        $namespace = $this->option('namespace');
        $model     = $this->option('model');
        $base_dir  = $this->option('base-dir');

        $data = [
            'MODEL'            => $model,
            'NAMESPACE'        => $namespace,
            'REPOSITORY'       => $model . 'Repository',
            'CONTROLLER'       => $model . 'sController',
            'CONTROLLER_MODEL' => strtolower($model),
            'TABLE'            => strtolower($model) . 's',
            'ROUTE'            => 'manager.' . strtolower($model) . 's',
            'VIEW'             => 'manager.' . strtolower($model) . 's',
        ];

        $this->generator->generate('model', $data, $base_dir);
        $this->generator->generate('repository', $data, $base_dir);
        $this->generator->generate('controller', $data, $base_dir);

        $this->generator->view('views.index', $data, $base_dir);
        $this->generator->view('views.form', $data, $base_dir);

        $this->info('CRUD criado com sucesso!');
        $this->info('');

        $this->info('Crie as seguintes rotas no seu arquivo routes.php!');
        $this->info('');

        $this->comment("Route::get('".$data['TABLE']."', ['as' => '".$data['ROUTE'].".index', 'uses' => '".$data['NAMESPACE']."\Controllers\Manager\\".$data['CONTROLLER']."@index']);");
        $this->comment("Route::get('".$data['TABLE']."/create', ['as' => '".$data['ROUTE'].".create', 'uses' => '".$data['NAMESPACE']."\Controllers\Manager\\".$data['CONTROLLER']."@create']);");
        $this->comment("Route::post('".$data['TABLE']."', ['as' => '".$data['ROUTE'].".store', 'uses' => '".$data['NAMESPACE']."\Controllers\Manager\\".$data['CONTROLLER']."@store']);");
        $this->comment("Route::get('".$data['TABLE']."/{id}/edit', ['as' => '".$data['ROUTE'].".edit', 'uses' => '".$data['NAMESPACE']."\Controllers\Manager\\".$data['CONTROLLER']."@edit']);");
        $this->comment("Route::put('".$data['TABLE']."/{id}', ['as' => '".$data['ROUTE'].".update', 'uses' => '".$data['NAMESPACE']."\Controllers\Manager\\".$data['CONTROLLER']."@update']);");
        $this->comment("Route::delete('".$data['TABLE']."/{id}', ['as' => '".$data['ROUTE'].".destroy', 'uses' => '".$data['NAMESPACE']."\Controllers\Manager\\".$data['CONTROLLER']."@destroy']);");

        $this->info('');
        $this->info('Não se esqueça de: ');
        $this->info(' -> Você deve criar a tabela manualmente utilizando o comando de migration do Laravel');
        $this->info(' -> Você precisa preencher os campos do formulário de view de form;');
        $this->info(' -> Alterar nomenclaturas nas views e no controller;');
        $this->info(' -> Adicionar regras de validação e fillable fiends no seu model;');
        $this->info(' -> TESTAR! TESTAR! e TESTAR!');
    }

    /**
     * Get the console command arguments.
     *
     * @return array
     */
    protected function getArguments()
    {
        return array();
    }

    /**
     * Get the console command options.
     *
     * @return array
     */
    protected function getOptions()
    {
        return array(
            array('model', 'mdl', InputOption::VALUE_REQUIRED, 'Nome do model'),
            array('namespace', 'nsp',  InputOption::VALUE_REQUIRED, 'O namespace onde o CRUD deve ser gerado'),
            array('base-dir', 'bdir',  InputOption::VALUE_REQUIRED, 'O diretório base onde os elementos devem ser gerados', 'app/src')
        );
    }
}
