<?php namespace EscapeWork\Manager\Controllers;

use EscapeWork\Manager\Repositories\PageRepository;
use EscapeWork\Manager\Repositories\PageActionRepository;
use EscapeWork\Manager\Repositories\RoleActionRepository;
use Input;
use Redirect;
use View;
use Config;

class PagesController extends ManagerController
{

    public function __construct(
        PageRepository $page,
        PageActionRepository $pageAction,
        RoleActionRepository $roleAction)
    {
        parent::__construct();

        $this->page       = $page;
        $this->pageAction = $pageAction;
        $this->roleAction = $roleAction;

        $this->validatePermissions('pages');
    }

    public function index()
    {
        $view        = View::make(Config::get('manager::views.pages.index'));
        $view->pages = $this->page->all();

        return $view;
    }

    public function create()
    {
        $view             = View::make(Config::get('manager::views.pages.form'));
        $view->page       = $this->page;
        $view->pageAction = $this->pageAction;
        $view->actions    = $this->pageAction->getDefaultActions();
        $view->edit       = false;

        return $view;
    }

    public function store()
    {
        $this->page->fill(Input::all());

        if (! $this->page->validate()) {
            return Redirect::route('manager.pages.create')
                    ->withInput()
                    ->with('errors', Page::$messages);
        }

        $this->page->save(Input::get('actions'));

        return Redirect::route('manager.pages.index')
                ->with('message', 'A página <strong>'.$this->page->title.'</strong> foi inserida com sucesso!');
    }

    public function edit($id)
    {
        $this->page = $this->page->findOrFail($id);

        $view             = View::make(Config::get('manager::views.pages.form'));
        $view->page       = $this->page;
        $view->pageAction = $this->pageAction;
        $view->edit       = true;
        $view->actions    = $this->pageAction->getByPage($this->page->id);

        return $view;
    }

    public function update($id)
    {
        $this->page = $this->page->findOrFail($id);
        $this->page->fill(Input::all());

        if (! $this->page->validate()) {
            return Redirect::route('manager.pages.edit', $this->page->id)
                    ->withInput()
                    ->withErros($this->page->messages());
        }

        $this->page->save(Input::get('actions'), true);

        return Redirect::route('manager.pages.index')
                       ->with('message', 'A regra <strong>'.$this->page->title.'</strong> foi atualizada com sucesso!');
    }

    public function destroy($id)
    {
        $this->page = $this->page->findOrFail($id);
        $this->page->delete();

        return Redirect::route('manager.pages.index')
                       ->with('message', 'A página <strong>'.$this->page->title.'</strong> foi excluída com sucesso!');
    }
}
