<?php namespace EscapeWork\Manager\Controllers;

use EscapeWork\Manager\Repositories\RoleRepository;
use EscapeWork\Manager\Repositories\PageRepository;
use EscapeWork\Manager\Facades\ManagerAuth;
use Input;
use Redirect;
use View;
use Config;

class RolesController extends ManagerController
{

    public function __construct(RoleRepository $role, PageRepository $page)
    {
        parent::__construct();

        $this->role = $role;
        $this->page = $page;

        $this->validatePermissions('roles');
    }

    /**
     * Listing the roles
     */
    public function index()
    {
        $view        = View::make(Config::get('manager::views.roles.index'));
        $view->roles = $this->role->allowed(ManagerAuth::user());

        return $view;
    }

    public function create()
    {
        $view        = View::make(Config::get('manager::views.roles.form'));
        $view->role  = $this->role;
        $view->edit  = false;
        $view->pages = $this->page->all();

        return $view;
    }

    public function store()
    {
        $this->role->fill(Input::all());

        if (! $this->role->validate()) {
            return Redirect::route('manager.roles.create')
                    ->withInput()
                    ->with('errors', $this->role->messages());
        }

        $this->role->save(
            Input::get('pages'),
            Input::get('actions')
        );

        return Redirect::route('manager.roles.index')
                ->with('message', 'O perfil <strong>'.$this->role->title.'</strong> foi inserido com sucesso!');
    }

    public function edit($id)
    {
        $this->role = $this->role->findOrFail($id);
        $this->role->load('pages');

        $view        = View::make(Config::get('manager::views.roles.form'));
        $view->role  = $this->role;
        $view->edit  = true;
        $view->pages = $this->page->all();

        return $view;
    }

    public function update($id)
    {
        $this->role = $this->role->findOrFail($id);
        $this->role->fill(Input::all());

        if (! $this->role->validate()) {
            return Redirect::route('manager.roles.edit', $this->role->id)
                    ->withInput()
                    ->withErrors($this->role->messages());
        }

        $this->role->save(
            Input::get('pages'),
            Input::get('actions'),
            true
        );

        return Redirect::route('manager.roles.index')
                ->with('message', 'O perfil <strong>'.$this->role->title.'</strong> foi atualizado com sucesso!');
    }

    /**
     * Destroying the role
     */
    public function destroy($id)
    {
        $this->role = $this->role->findOrFail($id);
        $this->role->delete();

        return Redirect::route('manager.roles.index')
                ->with('message', 'O perfil <strong>'.$this->role->title.'</strong> foi excluído com sucesso!');
    }
}
