<?php namespace EscapeWork\Manager\Controllers;

use EscapeWork\Manager\Repositories\UserRepository;
use EscapeWork\Manager\Repositories\UserReminderRepository;
use EscapeWork\Manager\Facades\ManagerPassword;
use View;
use Input;
use Redirect;
use Config;
use Lang;

class UserReminderController extends ManagerController
{

    public function __construct(
        UserRepository $user,
        UserReminderRepository $userReminder)
    {
        parent::__construct();

        $this->user         = $user;
        $this->userReminder = $userReminder;
    }

    public function send()
    {
        $credentials = array(
            'email' => Input::get('email')
        );

        if (! $user = $this->user->getByEmail($credentials['email'])) {
            return Redirect::route('manager.login')
                    ->with('error', 'Este e-mail não está cadastrado no sistema');
        }

        ManagerPassword::remind($credentials, function($m)
        {
            $m->subject('Seu lembrete de senha');
        });

        return Redirect::route('manager.login')
            ->with('message', 'Foi enviado para o seu e-mail instruções para refazer a sua senha.');
    }

    public function index($token)
    {
        if ( ! $this->userReminder->byToken($token)) {
            return Redirect::route('manager.login')
                        ->with('error', 'Token enviado é incorreto. Verifique o link enviado ao seu e-mail e tente novamente.');
        }

        $view           = View::make('manager::users.reset');
        $view->reminder = $this->userReminder;
        $view->token    = $token;

        return $view;
    }

    public function reset()
    {
        $credentials = Input::only('email', 'password', 'password_confirmation', 'token');

        if (! $user = $this->user->getByEmail($credentials['email'])) {
            return Redirect::route('manager.login')
                    ->with('error', 'O e-mail digitado para refazer a sua senha não existe!');
        }

        $response = ManagerPassword::reset($credentials, function($user, $password)
        {
            $user->password = $password;
            $user->save();
        });

        switch ($response) {
            case ManagerPassword::INVALID_PASSWORD:
                return Redirect::route('manager.password.reset', $credentials['token'])
                       ->with('error', Lang::get('manager::' . $response))
                       ->withInput();

            case ManagerPassword::INVALID_TOKEN:
            case ManagerPassword::INVALID_USER:
                return Redirect::route('manager.login')
                       ->with('error', Lang::get('manager::' . $response))
                       ->withInput();

            case ManagerPassword::PASSWORD_RESET:
                return Redirect::route('manager.login')
                       ->with('message', 'Sua senha foi alterada com sucesso! Faça o login agora.')
                       ->withInput();
        }
    }
}
