<?php namespace EscapeWork\Manager\Controllers;

use EscapeWork\Manager\Repositories\UserRepository;
use EscapeWork\Manager\Repositories\RoleRepository;
use EscapeWork\Manager\Facades\ManagerAuth;
use View;
use Input;
use Redirect;
use Config;
use Request;

class UsersController extends ManagerController
{

    public function __construct(
        UserRepository $user,
        RoleRepository $role)
    {
        parent::__construct();

        $this->user = $user;
        $this->role = $role;

        $this->validatePermissions('users');
    }

    public function index()
    {
        $view        = View::make(Config::get('manager::views.users.index'));
        $view->users = $this->user->allowed(ManagerAuth::user());

        return $view;
    }

    public function create()
    {
        $this->user->fill(Input::old());

        $view        = View::make(Config::get('manager::views.users.form'));
        $view->user  = $this->user;
        $view->roles = $this->role->allowed(ManagerAuth::user());
        $view->edit  = false;

        return $view;
    }

    public function store()
    {
        $this->user->fill(Input::all());

        if (! $this->user->validate()) {
            return Redirect::route('manager.users.create')
                    ->withInput()
                    ->withErrors($this->user->messages());
        }

        $this->user->save();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>' . $this->user->name . '</strong> foi inserido com sucesso!');
    }

    public function show($id)
    {
        if (Request::ajax()) {
            return $this->user->find($id);
        } else {
            return Redirect::route('manager.users.index');
        }
    }

    public function edit($id)
    {
        $this->user = $this->user->findOrFail($id);

        $view        = View::make(Config::get('manager::views.users.form'));
        $view->edit  = true;
        $view->user  = $this->user;
        $view->roles = $this->role->allowed(ManagerAuth::user());

        return $view;
    }

    public function update($id)
    {
        $this->user = $this->user->findOrFail($id);
        $this->user->fill(Input::all());

        if (! $this->user->validate()) {
            return Redirect::route('manager.users.edit', $this->user->id)
                            ->withInput()
                            ->withErrors($this->user->messages());
        }

        $this->user->save();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>'. $this->user->name .'</strong> foi editado com sucesso!');
    }

    public function destroy($id)
    {
        $this->user = $this->user->findOrFail($id);

        # verificando se o usuário logado não está tentando se excluir
        if (ManagerAuth::check() && $this->user->id == ManagerAuth::user()->id) {
            return Redirect::route('manager.users.index')
                    ->with('error', '<strong>'.$this->user->name.'</strong>, não é possível excluir o seu próprio usuário');
        }

        $this->user->delete();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>'.$this->user->name.'</strong> foi excluído com sucesso!');
    }
}
