<?php namespace EscapeWork\Manager\Providers;

use EscapeWork\Manager\Facades\ManagerAuth;
use EscapeWork\Manager\Permission;
use Illuminate\Support\ServiceProvider;
use Illuminate\Foundation\AliasLoader;

class ManagerServiceProvider extends ServiceProvider
{

    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        $this->package('escapework/manager', 'manager', realpath(__DIR__ . '/../../..'));

        require_once(__DIR__ . '/../../../routes.php');
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->registerPermission();
        $this->registerCommands();
        $this->callProviders();
        $this->createAliases();
        $this->createConfigurations();
    }

    /**
     * Registering the permission check class
     */
    protected function registerPermission()
    {
        $this->app['escapework.manager.permission'] = $this->app->share(function($app)
        {
            $user = ManagerAuth::user();

            $permission = $app->make('EscapeWork\Manager\Permission', array($user));
            $permission->fetchAllowedActions();

            return $permission;
        });
    }

    /**
     * Calling the providers needed
     */
    protected function callProviders()
    {
        $this->app->register('EscapeWork\Manager\Providers\UserServiceProvider');
        $this->app->register('EscapeWork\Manager\Providers\MacrosServiceProvider');

        if ($this->app['request']->is('manager/*')) {
            $this->app->register('EscapeWork\Manager\Providers\ErrorServiceProvider');
        }
    }

    protected function createAliases()
    {
        $this->app->booting(function()
        {
            $loader = AliasLoader::getInstance();

            $loader->alias('Check', 'EscapeWork\Manager\Facades\Check');
        });
    }

    /**
     * Registrando os comandos
     */
    public function registerCommands()
    {
        $this->app['command.manager.configure'] = $this->app->share(function($app)
        {
            return $app->make('EscapeWork\Manager\Commands\ConfigureCommand');
        });

        $this->app['command.manager.crud-generate'] = $this->app->share(function($app)
        {
            return $app->make('EscapeWork\Manager\Commands\CrudGenerateCommand');
        });

        $this->commands('command.manager.configure', 'command.manager.crud-generate');
    }

    /**
     * Criando as configurações em tempo de execução
     */
    protected function createConfigurations()
    {
        $this->app['config']->set('manager::packages', array());
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return array(
            'escapework.manager.permission',
            'command.manager.configure',
            'command.manager.crud-generate'
        );
    }
}
