<?php
/*
|--------------------------------------------------------------------------
| Rotas do pacote escapewo{{ Form::manager_messages($errors) }}rk/manager
|--------------------------------------------------------------------------
*/

# uses
use EscapeWork\Manager\Facades\ManagerAuth;

# ==================================================================
# filtro de login do manager
# ==================================================================
Route::filter('manager.auth', function()
{
    if (ManagerAuth::guest()) {
        return Redirect::intended(route('manager.login'));
    }
});

Route::filter('manager.guest', function()
{
    if (ManagerAuth::check()) return Redirect::route('manager.home');
});

Route::filter('manager.admin', function()
{
    if (! ManagerAuth::admin()) {
        return Redirect::route('manager.home')
                       ->with('warning', 'Você não tem permissão pra acessar esta página');
    }
});


# ==================================================================
# manager
# ==================================================================
Route::group(array('prefix' => Config::get('manager::url')), function()
{
    # ==================================================================
    # login
    # ==================================================================
    Route::get('login', array('as' => 'manager.login', 'uses' => Config::get('manager::controllers.login.index')));
    Route::post('login', Config::get('manager::controllers.login.login'));
    Route::get('logout', array('as' => 'manager.logout', 'uses' => Config::get('manager::controllers.login.logout')));


    # ==================================================================
    # grupo que precisa de autenticação
    # ==================================================================
    Route::group(array('before' => 'manager.auth'), function()
    {
        # home
         Route::get('/', array('as' => 'manager.home', 'uses' => Config::get('manager::controllers.home')));

        # usuários
        Route::get('usuarios', array('as' => 'manager.users.index', 'uses' => Config::get('manager::controllers.users.index')));
        Route::get('usuarios/create', array('as' => 'manager.users.create', 'uses' => Config::get('manager::controllers.users.create')));
        Route::post('usuarios', array('as' => 'manager.users.store', 'uses' => Config::get('manager::controllers.users.store')));
        Route::get('usuarios/{id}', array('as' => 'manager.users.show', 'uses' => Config::get('manager::controllers.users.show')));
        Route::get('usuarios/{id}/edit', array('as' => 'manager.users.edit', 'uses' => Config::get('manager::controllers.users.edit')));
        Route::put('usuarios/{id}', array('as' => 'manager.users.update', 'uses' => Config::get('manager::controllers.users.update')));
        Route::delete('usuarios/{id}', array('as' => 'manager.users.destroy', 'uses' => Config::get('manager::controllers.users.destroy')));

        # roles
        Route::get('perfis', array('as' => 'manager.roles.index', 'uses' => Config::get('manager::controllers.roles.index')));
        Route::get('perfis/create', array('as' => 'manager.roles.create', 'uses' => Config::get('manager::controllers.roles.create')));
        Route::post('perfis', array('as' => 'manager.roles.store', 'uses' => Config::get('manager::controllers.roles.store')));
        Route::get('perfis/{id}/edit', array('as' => 'manager.roles.edit', 'uses' => Config::get('manager::controllers.roles.edit')));
        Route::put('perfis/{id}', array('as' => 'manager.roles.update', 'uses' => Config::get('manager::controllers.roles.update')));
        Route::delete('perfis/{id}', array('as' => 'manager.roles.destroy', 'uses' => Config::get('manager::controllers.roles.destroy')));
    });


    # ==================================================================
    # grupo que precisa ser admin
    # ==================================================================
    Route::group(array('before' => 'manager.admin'), function()
    {
        # pages
        Route::get('paginas', array('as' => 'manager.pages.index', 'uses' => Config::get('manager::controllers.pages.index')));
        Route::get('paginas/create', array('as' => 'manager.pages.create', 'uses' => Config::get('manager::controllers.pages.create')));
        Route::post('paginas', array('as' => 'manager.pages.store', 'uses' => Config::get('manager::controllers.pages.store')));
        Route::get('paginas/{id}/edit', array('as' => 'manager.pages.edit', 'uses' => Config::get('manager::controllers.pages.edit')));
        Route::put('paginas/{id}', array('as' => 'manager.pages.update', 'uses' => Config::get('manager::controllers.pages.update')));
        Route::delete('paginas/{id}', array('as' => 'manager.pages.destroy', 'uses' => Config::get('manager::controllers.pages.destroy')));

        # logs
        Route::get('logs', array('as' => 'manager.logs.index', 'uses' => Config::get('manager::controllers.logs.index')));
        Route::get('logs/{log}', array('as' => 'manager.logs.show', 'uses' => Config::get('manager::controllers.logs.show')));
        Route::delete('logs/clear', array('as' => 'manager.logs.destroyAll', 'uses' => Config::get('manager::controllers.logs.destroyAll')));
        Route::delete('logs/{log}', array('as' => 'manager.logs.destroy', 'uses' => Config::get('manager::controllers.logs.destroy')));
    });

    # apenas quando não está logado
    Route::group(array('before' => 'manager.guest'), function()
    {
        # esqueci minha senha
        Route::get('esqueci-minha-senha', function()
        {
            return Redirect::route('manager.login');
        });

        Route::post('esqueci-minha-senha', array('as' => 'manager.usuarios.forgot.send', 'uses' => Config::get('manager::controllers.users.forgot.index')));
        Route::get('esqueci-minha-senha/reset/{token}', array('as' => 'manager.password.reset', 'uses' => Config::get('manager::controllers.users.forgot.reset')));
        Route::post('esqueci-minha-senha/reset', array('as' => 'manager.usuarios.reset.update', 'uses' => Config::get('manager::controllers.users.forgot.update')));
    });
});
