@extends(Config::get('manager::views.layouts.master'))

@section('content')
    {{ Form::manager_breadcrumb(array(route('manager.pages.index') => 'Páginas', $edit ? 'Editar' : 'Inserir')) }}

    {{ Form::manager_page_header(
        'Páginas',
        $edit ? 'Editar página' : 'Inserir página',
        array('route' => route('manager.pages.index'), 'label' => 'Cancelar')
    ) }}

    @include('manager::inc.messages')

    <form action="{{ !$edit ? route('manager.pages.store') : route('manager.pages.update', $page->id) }}" method="post" id="form-page" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put">
        @endif

        <fieldset>
            @section('fields')
                {{ Form::manager_form_group_input([
                    'label'      => 'Título',
                    'type'       => 'text',
                    'name'       => 'title',
                    'id'         => 'title',
                    'value'      => $page->title,
                    'required'   => true,
                    'autofocus'  => true
                ]) }}

                <div class="form-group">
                    <label for="specific_permissions" class="col-sm-2 control-label">Permissões</label>

                    <div class="col-sm-8">
                        <div class="checkbox">
                            <label>
                                <input type="checkbox" name="specific_permissions" id="specific_permissions" value="1" {{ $page->specific_permissions ? 'checked="checked"' : null }}>
                                Esta página possui permissões específicas para determinadas ações?
                            </label>
                        </div>
                    </div>
                </div>
            @show
        </fieldset>

        <hr>

        <fieldset id="specific-permissions-container" {{ $page->specific_permissions ?: 'style="display: none"' }}">
            <legend>Ações da página</legend>

            <div class="form-group">
                <div class="col-sm-8 col-sm-offset-2">
                    <dl class="dl-horizontal" id="actions">
                        @foreach ($actions as $i => $action)
                            <dt class="js-form-group-page-actions">
                                <input type="hidden" name="actions[{{ $i }}][title]" value="{{ $action->title }}">
                                <input type="hidden" name="actions[{{ $i }}][type]" value="{{ $action->type }}">

                                {{ $action->title }} (<small>{{ $action->type }}</small>) &nbsp;
                            </dt>

                            <dd style="margin-bottom: 10px">
                                <button type="button" data-delete-action class="btn btn-xs btn-danger" title="Excluir">
                                    <i class="glyphicon glyphicon-trash"></i>
                                </button>
                            </dd>
                        @endforeach
                    </ul>
                </div><!-- #acoes -->
            </div><!-- .control-group -->

            <div class="form-group">
                <div class="col-sm-6 col-sm-offset-2">
                    <div class="input-group">
                        <input type="text" class="form-control" style="width: 50%" id="actionTitle" placeholder="Digite a ação...">
                        <input type="text" class="form-control" style="width: 50%" id="actionType" placeholder="Digite o tipo...">

                        <span class="input-group-btn">
                            <button type="button" class="btn btn-success" id="js-add-action">Adicionar ação</button>
                        </span>
                    </div><!-- .input-group -->

                    <span class="help-block">O tipo da ação será utilizado na validação das permissões, deve ser um nome sem espaços e/ou caracteres especiais.</span>
                </div><!-- .controls -->
            </div><!-- .control-group -->
        </fieldset>

        <div class="form-group">
            <div class="col-sm-9 col-sm-offset-2">
                <button type="submit" class="btn btn-primary js-btn-submit" data-loading-text="Aguarde...">Salvar</button>
                <a href="{{ route('manager.pages.index') }}" class="btn">Cancelar</a>
            </div>
        </div><!-- .form-group -->
    </form>

    <script type="text/template" id="template-action">
        <dt>
            <input type="hidden" name="actions[##i##][title]" value="##title##">
            <input type="hidden" name="actions[##i##][type]" value="##type##">

            ##title## (<small>##type##</small>) &nbsp;
        </dt>

        <dd style="margin-bottom: 10px">
            <button type="button" data-delete-action class="btn btn-xs btn-danger">
                <i class="glyphicon glyphicon-trash"></i>
            </button>
        </dd>
    </script>
@stop

@section('scripts')
    @parent

    <script type="text/javascript" src="{{ asset('packages/escapework/manager/assets/js/pages/form.js') }}"></script>
@stop
