@extends(Config::get('manager::views.layouts.master'))

@section('content')
    {{ Form::manager_breadcrumb([route('manager.users.index') => 'Usuários', route('manager.roles.index') => 'Perfis', $edit ? 'Editar' : 'Inserir']) }}

    {{ Form::manager_page_header(
        'Perfis',
        $edit ? 'Editar perfil' : 'Inserir perfil',
        array('route' => route('manager.roles.index'), 'label' => 'Cancelar')
    ) }}

    @include('manager::inc.messages')

    <form action="{{ !$edit ? route('manager.roles.store') : route('manager.roles.update', $role->id) }}" method="post" id="form-role" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put">
        @endif

        <fieldset>
            @section('fields')
                {{ Form::manager_form_group_input([
                    'label'      => 'Título',
                    'type'       => 'text',
                    'name'       => 'title',
                    'id'         => 'title',
                    'value'      => $role->title,
                    'required'   => true,
                    'autofocus'  => true
                ]) }}

                <div class="form-group">
                    <label class="col-sm-2 control-label">Todas permissões liberadas?</label>

                    <div class="col-sm-8">
                        <div class="inline radio">
                            <label>
                                <input type="radio" name="all_permissions" value="1" {{ $role->all_permissions ? 'checked="checked"' : null }}>
                                Sim
                            </label>
                        </div>

                        <div class="inline radio">
                            <label>
                                <input type="radio" name="all_permissions" value="0" {{ !$role->all_permissions ? 'checked="checked"' : null }}>
                                Não
                            </label>
                        </div>
                    </div><!-- .controls -->
                </div><!-- .control-group -->
            </fieldset>

            <hr>

            <fieldset id="box-permissions" class="{{ $role->all_permissions ? 'hide' : '' }}">
                <legend>Páginas e Permissões</legend>

                @foreach ($pages as $page)
                    <div class="form-group">
                        <label class="col-sm-2 control-label">{{ $page->title }}</label>

                        <div class="col-sm-8 js-controls-permissions">
                            <div class="checkbox">
                                <label>
                                    <input type="checkbox" name="pages[]" value="{{ $page->id }}" {{ $role->pages->contains($page->id) ? 'checked="checked"' : null }}>
                                    Marque para este checkbox ter acesso a esta página
                                </label>
                            </div><!-- .checkbox -->

                            @if ($page->actions->count() > 0)
                                <br>
                                @foreach ($page->actions as $action)
                                    <div class="checkbox">
                                        <label>
                                            <input type="checkbox" name="actions[{{ $page->id }}][]" value="{{ $action->id }}" {{ $role->actions->contains($action->id) ? 'checked="checked"' : null }}>
                                            <strong>{{ $action->title }}</strong> <small>(Acesso para esta ação específica da página <strong>{{ $page->title }}</strong>)</small>
                                        </label>
                                    </div>
                                @endforeach
                            @endif
                        </div><!-- .controls -->
                    </div><!-- .form-group -->
                @endforeach
            @show
        </fieldset>

        <div class="form-group">
            <div class="col-sm-offset-2 col-sm-10">
                <button type="submit" class="btn btn-primary js-btn-submit" data-loading-text="Carregando...">Salvar</button>
                <a href="{{ route('manager.roles.index') }}" class="btn">Cancelar</a>
            </div><!-- .form-actions -->
        </div>
    </form>
@stop

@section('scripts')
    @parent
    <script type="text/javascript" src="{{ asset('packages/escapework/manager/assets/js/roles/form.js') }}"></script>
@stop
